summaryrefslogtreecommitdiff
path: root/source4/build
diff options
context:
space:
mode:
Diffstat (limited to 'source4/build')
-rw-r--r--source4/build/pidl/swig.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/source4/build/pidl/swig.pm b/source4/build/pidl/swig.pm
index 2b8daf40ff..11894719f5 100644
--- a/source4/build/pidl/swig.pm
+++ b/source4/build/pidl/swig.pm
@@ -709,9 +709,9 @@ sub RewriteHeader($$$)
s/dom_sid2/dom_sid/g;
- # Copy structure definitions
+ # Copy structure and union definitions
- if (/^struct .*? {$/ .. /^\};$/) {
+ if (/^(struct|union) .*? {$/ .. /^\};$/) {
s/\} (in|out);/\} data_$1;/; # "in" is a Python keyword
pidl $_;
next;